import React from 'react';
import renderer from 'react-test-renderer';
import {createMockSpark} from '@ciscospark/react-redux-spark-fixtures';

import SparkOAuth from '.';

describe('SparkOAuth component', () => {
  const component = renderer.create(<SparkOAuth />);

  it('renders properly', () => {
    expect(component).toMatchSnapshot();
  });
});

describe('SparkOAuth functionality', () => {
  let onAuth, spark, sparkOAuth;

  beforeEach(() => {
    onAuth = jest.fn();
    sparkOAuth = new SparkOAuth({doAuth: false, onAuth});
    spark = createMockSpark();
    sparkOAuth.spark = spark;
  });

  it('should call spark auth when told', () => {
    sparkOAuth.props.doAuth = false;
    const props = {doAuth: true};

    sparkOAuth.componentWillReceiveProps(props);
    expect(spark.authenticate).toHaveBeenCalled();
  });

  it('should call onAuth after a successful authorization', () => {
    spark.credentials.canAuthorize = true;
    spark.credentials.supertoken = 'supertoken';
    sparkOAuth.checkForOauthToken();
    expect(onAuth).toHaveBeenCalled();
  });

  it('should not call onAuth when not authorized', () => {
    spark.credentials.canAuthorize = false;
    spark.credentials.supertoken = 'supertoken';
    sparkOAuth.checkForOauthToken();
    expect(onAuth).not.toHaveBeenCalled();
  });
});
